[![PyPI](https://img.shields.io/pypi/v/pymdgen.svg?maxAge=3600)](https://pypi.python.org/pypi/pymdgen)
[![PyPI](https://img.shields.io/pypi/pyversions/pymdgen.svg?maxAge=600)](https://pypi.python.org/pypi/pymdgen)
[![Travis CI](https://img.shields.io/travis/20c/pymdgen.svg?maxAge=3600)](https://travis-ci.org/20c/pymdgen)
[![Codecov](https://img.shields.io/codecov/c/github/20c/pymdgen/master.svg?maxAge=3600)](https://codecov.io/github/20c/pymdgen)
[![Requires.io](https://img.shields.io/requires/github/20c/pymdgen.svg?maxAge=3600)](https://requires.io/github/20c/pymdgen/requirements)

A python code markdown documentation generator

# Documentation

- [latest](https://pymdgen.readthedocs.io/en/latest/)


